@@ -3,8 +3,9 @@ Main interface for apigateway service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.apigateway import (
+    from mypy_boto3_apigateway import (
         APIGatewayClient,
         Client,
         GetApiKeysPaginator,
@@ -25,7 +26,7 @@ Usage::
         GetUsagePlanKeysPaginator,
         GetUsagePlansPaginator,
         GetVpcLinksPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -50,8 +51,9 @@ Usage::
     get_usage_plan_keys_paginator: GetUsagePlanKeysPaginator = client.get_paginator("get_usage_plan_keys")
     get_usage_plans_paginator: GetUsagePlansPaginator = client.get_paginator("get_usage_plans")
     get_vpc_links_paginator: GetVpcLinksPaginator = client.get_paginator("get_vpc_links")
+    ```
 """
-from mypy_boto3_apigateway.client import APIGatewayClient, APIGatewayClient as Client
+from mypy_boto3_apigateway.client import APIGatewayClient
 from mypy_boto3_apigateway.paginator import (
     GetApiKeysPaginator,
     GetAuthorizersPaginator,
@@ -73,6 +75,8 @@ from mypy_boto3_apigateway.paginator import (
     GetVpcLinksPaginator,
 )
 
+Client = APIGatewayClient
+
 
 __all__ = (
     "APIGatewayClient",
