@@ -18,6 +18,8 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -46,6 +48,7 @@ __all__ = (
     "MethodSnapshotTypeDef",
     "MethodTypeDef",
     "ModelTypeDef",
+    "MutualTlsAuthenticationTypeDef",
     "QuotaSettingsTypeDef",
     "RequestValidatorTypeDef",
     "ResourceTypeDef",
@@ -73,6 +76,7 @@ __all__ = (
     "ExportResponseTypeDef",
     "GatewayResponsesTypeDef",
     "ModelsTypeDef",
+    "MutualTlsAuthenticationInputTypeDef",
     "PaginatorConfigTypeDef",
     "PatchOperationTypeDef",
     "RequestValidatorsTypeDef",
@@ -237,6 +241,7 @@ DomainNameTypeDef = TypedDict(
         "domainNameStatusMessage": str,
         "securityPolicy": Literal["TLS_1_0", "TLS_1_2"],
         "tags": Dict[str, str],
+        "mutualTlsAuthentication": "MutualTlsAuthenticationTypeDef",
     },
     total=False,
 )
@@ -367,6 +372,12 @@ ModelTypeDef = TypedDict(
     total=False,
 )
 
+MutualTlsAuthenticationTypeDef = TypedDict(
+    "MutualTlsAuthenticationTypeDef",
+    {"truststoreUri": str, "truststoreVersion": str, "truststoreWarnings": List[str]},
+    total=False,
+)
+
 QuotaSettingsTypeDef = TypedDict(
     "QuotaSettingsTypeDef",
     {"limit": int, "offset": int, "period": Literal["DAY", "WEEK", "MONTH"]},
@@ -579,6 +590,12 @@ ModelsTypeDef = TypedDict(
     "ModelsTypeDef", {"position": str, "items": List["ModelTypeDef"]}, total=False
 )
 
+MutualTlsAuthenticationInputTypeDef = TypedDict(
+    "MutualTlsAuthenticationInputTypeDef",
+    {"truststoreUri": str, "truststoreVersion": str},
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
